==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/directoryview.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef DIRECTORYVIEW_H
#define DIRECTORYVIEW_H

#include "mpdsonglist.h"
#include <QTreeView>

class DirectoryModel;
class MPD;
class MPDDirectory;

class DirectoryView : public QTreeView {
	Q_OBJECT
private:
	bool m_midButtonDrag;
	DirectoryModel *m_model;
	MPD *m_mpd;
	QAction *m_enqueueAction, *m_playAction, *m_informationAction;
	QMenu *m_menu;
	void mouseMoveEvent(QMouseEvent *);
	void mousePressEvent(QMouseEvent *);
	void mouseReleaseEvent(QMouseEvent *);
	QList<MPDDirectory *> selectedDirectories();

public:
	DirectoryView(QWidget *);

private slots:
	void activated(const QModelIndex &);
	void contextMenuEvent(QContextMenuEvent *);
	void enqueue();
	void information();
	void play();
	void selectionChanged(const QItemSelection &, const QItemSelection &);
	void setRoot(MPDDirectory *);
	void startDrag(Qt::DropActions);
	void toggleActions();

signals:
	void directoryChanged(MPDSongList);
};

#endif

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/directoryview.h <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef DIRECTORYVIEW_H
#define DIRECTORYVIEW_H

#include "mpdsonglist.h"
#include <QTreeView>

class DirectoryView : public QTreeView {
	Q_OBJECT
private:
	bool m_midButtonDrag;
	class DirectoryModel *m_model;
	class MPD *m_mpd;
	QAction *m_enqueueAction, *m_playAction, *m_informationAction;
	QMenu *m_menu;
	void mouseMoveEvent(QMouseEvent *);
	void mousePressEvent(QMouseEvent *);
	void mouseReleaseEvent(QMouseEvent *);

public:
	DirectoryView(QWidget *);

private slots:
	void activated(const QModelIndex &);
	void contextMenuEvent(QContextMenuEvent *);
	void enqueue();
	void information();
	void play();
	void rescan();
	void selectionChanged(const QItemSelection &, const QItemSelection &);
	void setRoot(class MPDDirectory *);
	void toggleActions();

signals:
	void directoryChanged(const MPDSongList &);
};

#endif
